@@ -1,6 +1,7 @@
 # Standard
 import ast
-import importlib
+import inspect
+import pydoc
 import signal
 import socket
 import traceback
@@ -210,7 +211,8 @@ class Sentinel:
         :param process: the process to reincarnate
         :type process: Process or None
         """
-        close_old_django_connections()
+        if not Conf.SYNC:
+            db.connections.close_all()  # Close any old connections
         if process == self.monitor:
             self.monitor = self.spawn_monitor()
             logger.error(_(f"reincarnated monitor {process.name} after sudden death"))
@@ -234,7 +236,8 @@ class Sentinel:
     def spawn_cluster(self):
         self.pool = []
         Stat(self).save()
-        close_old_django_connections()
+        if not Conf.SYNC:
+            db.connection.close()
         # spawn worker pool
         for __ in range(self.pool_size):
             self.spawn_worker()
@@ -416,31 +419,22 @@ def worker(
         f = task["func"]
         # if it's not an instance try to get it from the string
         if not callable(task["func"]):
-            try:
-                module, func = f.rsplit(".", 1)
-                m = importlib.import_module(module)
-                f = getattr(m, func)
-            except (ValueError, ImportError, AttributeError) as e:
-                result = (e, False)
-                if error_reporter:
-                    error_reporter.report()
-        # We're still going
-        if not result:
-            close_old_django_connections()
-            timer_value = task.pop("timeout", timeout)
-            # signal execution
-            pre_execute.send(sender="django_q", func=f, task=task)
-            # execute the payload
-            timer.value = timer_value  # Busy
-            try:
-                res = f(*task["args"], **task["kwargs"])
-                result = (res, True)
-            except Exception as e:
-                result = (f"{e} : {traceback.format_exc()}", False)
-                if error_reporter:
-                    error_reporter.report()
-                if task.get("sync", False):
-                    raise
+            f = pydoc.locate(f)
+        close_old_django_connections()
+        timer_value = task.pop("timeout", timeout)
+        # signal execution
+        pre_execute.send(sender="django_q", func=f, task=task)
+        # execute the payload
+        timer.value = timer_value  # Busy
+        try:
+            res = f(*task["args"], **task["kwargs"])
+            result = (res, True)
+        except Exception as e:
+            result = (f"{e} : {traceback.format_exc()}", False)
+            if error_reporter:
+                error_reporter.report()
+            if task.get("sync", False):
+                raise
         with timer.get_lock():
             # Process result
             task["result"] = result[0]
@@ -476,8 +470,10 @@ def save_task(task, broker: Broker):
     # SAVE LIMIT > 0: Prune database, SAVE_LIMIT 0: No pruning
     close_old_django_connections()
     try:
-        if task["success"] and 0 < Conf.SAVE_LIMIT <= Success.objects.count():
-            Success.objects.last().delete()
+        with db.transaction.atomic():
+            last = Success.objects.select_for_update().last()
+            if task["success"] and 0 < Conf.SAVE_LIMIT <= Success.objects.count():
+                last.delete()
         # check if this task has previous results
         if Task.objects.filter(id=task["id"], name=task["name"]).exists():
             existing_task = Task.objects.get(id=task["id"], name=task["name"])
@@ -493,10 +489,19 @@ def save_task(task, broker: Broker):
                 broker.acknowledge(task['ack_id'])
 
         else:
+            func = task["func"]
+            # convert func to string
+            if inspect.isfunction(func):
+                func = f"{func.__module__}.{func.__name__}"
+            elif inspect.ismethod(func):
+                func = (
+                    f'{func.__self__.__module__}.'
+                    f'{func.__self__.__name__}.{func.__name__}'
+                )
             Task.objects.create(
                 id=task["id"],
                 name=task["name"],
-                func=task["func"],
+                func=func,
                 hook=task.get("hook"),
                 args=task["args"],
                 kwargs=task["kwargs"],
@@ -576,6 +581,7 @@ def scheduler(broker: Broker = None):
                 Schedule.objects.select_for_update()
                 .exclude(repeats=0)
                 .filter(next_run__lt=timezone.now())
+                .filter(db.models.Q(cluster__isnull=True) | db.models.Q(cluster=Conf.PREFIX))
             ):
                 args = ()
                 kwargs = {}
@@ -620,7 +626,7 @@ def scheduler(broker: Broker = None):
                                     )
                                 )
                             next_run = arrow.get(
-                                croniter(s.cron, timezone.now()).get_next()
+                                croniter(s.cron, timezone.localtime()).get_next()
                             )
                         if Conf.CATCH_UP or next_run > arrow.utcnow():
                             break
@@ -727,4 +733,4 @@ def rss_check():
             return resource.getrusage(resource.RUSAGE_SELF).ru_maxrss >= Conf.MAX_RSS
         elif psutil:
             return psutil.Process().memory_info().rss >= Conf.MAX_RSS * 1024
-    return False
+    return False
\ No newline at end of file
