@@ -1,29 +1,32 @@
 import pytest
+import uuid
 
 from django_q.tasks import async_task
 from django_q.brokers import get_broker
 from django_q.cluster import Cluster
-from django_q.monitor import monitor, info
+from django_q.monitor import monitor, info, get_ids
 from django_q.status import Stat
 from django_q.conf import Conf
 
 
 @pytest.mark.django_db
 def test_monitor(monkeypatch):
-    assert Stat.get(0).sentinel == 0
+    cluster_id = uuid.uuid4()
+    assert Stat.get(pid=0, cluster_id=cluster_id).sentinel == 0
     c = Cluster()
     c.start()
     stats = monitor(run_once=True)
+    assert get_ids() is True
     c.stop()
     assert len(stats) > 0
     found_c = False
     for stat in stats:
-        if stat.cluster_id == c.pid:
+        if stat.cluster_id == c.cluster_id:
             found_c = True
             assert stat.uptime() > 0
             assert stat.empty_queues() is True
             break
-    assert found_c is True
+    assert found_c
     # test lock size
     monkeypatch.setattr(Conf, 'ORM', 'default')
     b = get_broker('monitor_test')
